@@ -348,11 +348,11 @@ def get_payload_command(job):
     #if not userjob and use_direct_access and job.transfertype == 'direct':
     if not userjob and not job.is_build_job() and job.has_remoteio():  ## ported from old logic
         ## ported from old logic but still it looks strange (anisyonk)
-        ## the "PoolFileCatalogger.xml" should already contains proper TURLs values as it created by create_input_file_metadata()
+        ## the "PoolFileCatalog.xml" should already contains proper TURLs values as it created by create_input_file_metadata()
         ## if the case is just to patch `writetofile` file, than logic should be cleaned and decoupled
         ## anyway, instead of parsing the file, it's much more easy to generate properly `writetofile` content from the beginning with TURL data
         lfns = job.get_lfns_and_guids()[0]
-        cmd = replace_lfns_with_turls(cmd, job.workdir, "PoolFileCatalogger.xml", lfns, writetofile=job.writetofile)
+        cmd = replace_lfns_with_turls(cmd, job.workdir, "PoolFileCatalog.xml", lfns, writetofile=job.writetofile)
 
     # Explicitly add the ATHENA_PROC_NUMBER (or JOB value)
     cmd = add_athena_proc_number(cmd)
@@ -1509,7 +1509,7 @@ def get_redundants():
                 "*proxy",
                 "ckpt*",
                 "*runcontainer*",
-                "*job.logger.tgz",
+                "*job.log.tgz",
                 "runGen-*",
                 "runAthena-*",
                 "pandawnutil/*",
@@ -1593,7 +1593,7 @@ def remove_special_files(workdir, dir_list, outputfiles):
     """
 
     # note: these should be partial file/dir names, not containing any wildcards
-    exceptions_list = ["runargs", "runwrapper", "jobReport", "logger."]
+    exceptions_list = ["runargs", "runwrapper", "jobReport", "log."]
 
     to_delete = []
     for _dir in dir_list:
@@ -1678,13 +1678,12 @@ def remove_redundant_files(workdir, outputfiles=[], islooping=False):
     ls(workdir)
 
 
-def download_command(process, workdir, label='preprocess'):
+def download_command(process, workdir):
     """
     Download the pre/postprocess commands if necessary.
 
     :param process: pre/postprocess dictionary.
     :param workdir: job workdir (string).
-    :param label: pre/postprocess label (string).
     :return: updated pre/postprocess dictionary.
     """
 
@@ -1695,7 +1694,7 @@ def download_command(process, workdir, label='preprocess'):
         # Try to download the trf (skip when user container is to be used)
         ec, diagnostics, cmd = get_analysis_trf(cmd, workdir)
         if ec != 0:
-            logger.warning('cannot execute %s command due to previous error' % label)
+            logger.warning('cannot execute command due to previous error: %s' % cmd)
             return {}
 
         # update the preprocess command (the URL should be stripped)
@@ -1726,19 +1725,21 @@ def get_utility_commands(order=None, job=None):
     if order:
         if order == UTILITY_BEFORE_PAYLOAD and job and job.preprocess:
             if job.preprocess.get('command', ''):
-                return download_command(job.preprocess, job.workdir, label='preprocess')
+                return download_command(job.preprocess, job.workdir)
         elif order == UTILITY_WITH_PAYLOAD:
             return {'command': 'NetworkMonitor', 'args': ''}
-        elif order == UTILITY_AFTER_PAYLOAD_STARTED:
-            cmd = config.Pilot.utility_after_payload_started
-            if cmd:
-                return {'command': cmd, 'args': ''}
+        elif order == UTILITY_AFTER_PAYLOAD_STARTED and job and job.coprocess:
+            # cmd = config.Pilot.utility_after_payload_started  DEPRECATED
+            #if cmd:
+            #    return {'command': cmd, 'args': ''}
+            if job.coprocess.get('command', ''):
+                return download_command(job.coprocess, job.workdir)
         elif order == UTILITY_AFTER_PAYLOAD and job and job.postprocess:
             if job.postprocess.get('command', ''):
-                return download_command(job.postprocess, job.workdir, label='postprocess')
+                return download_command(job.postprocess, job.workdir)
         elif order == UTILITY_AFTER_PAYLOAD_FINISHED and job and job.postprocess:
             if job.postprocess.get('command', ''):
-                return download_command(job.postprocess, job.workdir, label='postprocess')
+                return download_command(job.postprocess, job.workdir)
         elif order == UTILITY_WITH_STAGEIN:
             return {'command': 'Benchmark', 'args': ''}
 
